OSSP CVS Repository

ossp - Difference in ossp-pkg/as/as-gui/as_assist.cpp versions 1.17 and 1.18
Not logged in
[Honeypot]  [Browse]  [Home]  [Login]  [Reports
[Search]  [Ticket]  [Timeline
  [History

ossp-pkg/as/as-gui/as_assist.cpp 1.17 -> 1.18

--- as_assist.cpp        2002/11/25 16:23:35     1.17
+++ as_assist.cpp        2002/11/26 14:10:32     1.18
@@ -244,15 +244,21 @@
 //
 void Titraqform::setupFiletools(void)
 {
-    // Construct and populate the main tool bar
-    m_pToolbar = new QToolBar("Toolfile", this, DockTop);
-    if (m_pToolbar == NULL) // Sanity check
-        throw Genexcept("Main window tool bar creation failed.");
-    m_pToolbar->setLabel(trUtf8("File Ops"));
-    m_pFilenewact->addTo(m_pToolbar);
-    m_pFileopenact->addTo(m_pToolbar);
-    m_pFilesaveact->addTo(m_pToolbar);
-    QWhatsThis::whatsThisButton(m_pToolbar); // Preconfigured whats this button
+    // Construct and populate the file tool bar
+    m_pFiletools = new QToolBar("Toolfile", this, DockTop);
+    if (m_pFiletools == NULL)                   // Sanity check
+        throw Genexcept("File tool bar creation failed.");
+    m_pFiletools->setLabel(trUtf8("File Ops"));
+    m_pFilenewact->addTo(m_pFiletools);
+    m_pFileopenact->addTo(m_pFiletools);
+    m_pFilesaveact->addTo(m_pFiletools);
+    QWhatsThis::whatsThisButton(m_pFiletools);  // Preconfigured whats this button
+
+    // Construct and populate the edit tool bar
+    m_pEdittools = new QToolBar("Tooledit", this, DockTop);
+    if (m_pEdittools == NULL)                   // Sanity check
+        throw Genexcept("Edit tool bar creation failed.");
+    m_pEdittools->setLabel(trUtf8("Edit Ops"));
 }
 
 //

CVSTrac 2.0.1